@@ -204,3 +204,8 @@ class AuditTrailViewSet(NestedViewSetMixin, viewsets.ReadOnlyModelViewSet):
             else:
                 raise Http404
         return qs
+
+    def parent_lookup_kwargs(self):
+        return {
+            self.main_resource_lookup_field: "hoofd_object__contains",
+        }
